==> dd_taoke_sdk-0.2.2.tar.gz: lib/model/ddq_result.dart <==
// To parse this JSON data, do
//
//     final ddqResult = ddqResultFromJson(jsonString);

import 'dart:convert';

import 'package:dd_taoke_sdk/model/product.dart';

DdqResult ddqResultFromJson(String str) => DdqResult.fromJson(json.decode(str));

String ddqResultToJson(DdqResult data) => json.encode(data.toJson());

class DdqResult {
  DdqResult({
    this.roundsList,
    this.goodsList,
    this.ddqTime,
    this.status,
  });

  List<RoundsList> roundsList;
  List<Product> goodsList;
  DateTime ddqTime;
  int status;

  factory DdqResult.fromJson(Map<String, dynamic> json) => DdqResult(
        roundsList: List<RoundsList>.from(
            json["roundsList"].map((x) => RoundsList.fromJson(x))),
        goodsList: List<Product>.from(
            json["goodsList"].map((x) => Product.fromJson(x))),
        ddqTime: DateTime.parse(json["ddqTime"]),
        status: json["status"],
      );

  Map<String, dynamic> toJson() => {
        "roundsList": List<dynamic>.from(roundsList.map((x) => x.toJson())),
        "goodsList": jsonEncode(goodsList),
        "ddqTime": ddqTime.toIso8601String(),
        "status": status,
      };
}

class RoundsList {
  RoundsList({
    this.ddqTime,
    this.status,
  });

  DateTime ddqTime;
  int status;

  factory RoundsList.fromJson(Map<String, dynamic> json) => RoundsList(
        ddqTime: DateTime.parse(json["ddqTime"]),
        status: json["status"],
      );

  Map<String, dynamic> toJson() => {
        "ddqTime": ddqTime.toIso8601String(),
        "status": status,
      };
}

==> dd_taoke_sdk-1.2.2.tar.gz: lib/model/ddq_result.dart <==
// To parse this JSON data, do
//
//     final ddqResult = ddqResultFromJson(jsonString);

import 'dart:convert';

import 'package:dd_taoke_sdk/model/product.dart';

DdqResult ddqResultFromJson(String str) => DdqResult.fromJson(json.decode(str));

String ddqResultToJson(DdqResult data) => json.encode(data.toJson());

class DdqResult {
  DdqResult({
    this.roundsList,
    this.goodsList,
    this.ddqTime,
    this.status,
  });

  List<RoundsList>? roundsList;
  List<Product>? goodsList;
  DateTime? ddqTime;
  int? status;

  factory DdqResult.fromJson(Map<String, dynamic> json) => DdqResult(
        roundsList: List<RoundsList>.from(
            json["roundsList"].map((x) => RoundsList.fromJson(x))),
        goodsList: List<Product>.from(
            json["goodsList"].map((x) => Product.fromJson(x))),
        ddqTime: DateTime.parse(json["ddqTime"]),
        status: json["status"],
      );

  Map<String, dynamic> toJson() => {
        "roundsList": List<dynamic>.from(roundsList!.map((x) => x.toJson())),
        "goodsList": jsonEncode(goodsList),
        "ddqTime": ddqTime!.toIso8601String(),
        "status": status,
      };
}

class RoundsList {
  RoundsList({
    this.ddqTime,
    this.status,
  });

  DateTime? ddqTime;
  int? status;

  factory RoundsList.fromJson(Map<String, dynamic> json) => RoundsList(
        ddqTime: DateTime.parse(json["ddqTime"]),
        status: json["status"],
      );

  Map<String, dynamic> toJson() => {
        "ddqTime": ddqTime!.toIso8601String(),
        "status": status,
      };
}
